@@ -11,7 +11,7 @@ setMethod("gain", signature=c(object="PSTf"), function(object, node, f, C) {
 
 	for (n in 1:length(seglist)) {
 		if (f=="G2") {
-			res[n] <- G2(node@prob[n,], parent@prob[seqglist[n],], C=C, N=node@n[n])
+			res[n] <- G2(node@prob[n,], parent@prob[seglist[n],], C=C, N=node@n[n])
 		} else if (f=="G1") {
 			res[n] <- G1(node@prob[n,], parent@prob[seglist[n],], C=C)
 		}
